[![NPM][npm]][npm-url]
[![Node][node]][node-url]
[![Dependencies][deps]][deps-url]
[![DevDependencies][devdeps]][devdeps-url]
[![Standard Code Style][style]][style-url]

<div align="center">
  <img width="150" height="150" title="Hapi" src="https://worldvectorlogo.com/logos/hapi.svg">
  <img width="200" height="150" title="PostHTML" src="http://posthtml.github.io/posthtml/logo.svg">
</div>

## Install

```bash
$ npm i -S hapi-posthtml
```

## Usage

```js
'use strict'

const Hapi = require('hapi')

const server = new Hapi.Server()

// Create a server with host and port
server.connection({
  host: 'localhost',
  port: 3000
})

// Register vision for view support
server.register(require('vision'), err => {
  if (err) {
    throw err
  }
  // Setup views with PostHTML
  server.views({
    path: 'public/views/',
    engines: {
      'html': require('hapi-posthtml')
    },
    relativeTo: __dirname,
    compileMode: 'async'
    compileOptions: {
      // Set PostHTML Plugins
      plugins: [/* Plugins */]
    }
  })
})

// Create route handlers
let handlers = {
  root: function (request, reply) {
    reply.view('index')
  },
  local: function (request, reply) {
    reply.view('index', {plugins: [/* Plugins */]})
  },
  extend: function (request, reply) {
    reply.view('index', {plugins: [/* Plugins */], extend: true})
  }
}

// Add the routes
server.route({
  method: 'GET',
  path: '/',
  handler: handlers.root
})

server.route({
  method: 'GET',
  path: '/local',
  handler: handlers.local
})

server.route({
  method: 'GET',
  path: '/extend',
  handler: handlers.extend
})

// Start the server
server.start((err) => {
  if (err) {
    throw err
  }
  console.log('=> Server:', server.info.uri)
})
```

## LICENSE

> MIT License (MIT)

> Copyright (c) 2016 Michael Ciniawsky

> Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

> The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

> THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

[npm]: https://img.shields.io/npm/v/hapi-posthtml.svg
[npm-url]: https://npmjs.com/package/hapi-posthtml

[node]: https://img.shields.io/node/v/gh-badges.svg?maxAge=2592000
[node-url]: https://nodejs.org

[deps]: https://david-dm.org/posthtml/hapi-posthtml.svg
[deps-url]: https://david-dm.org/posthtml/hapi-posthtml

[devdeps]: https://david-dm.org/posthtml/hapi-posthtml/dev-status.svg
[devdeps-url]: https://david-dm.org/posthtml/hapi-posthtml#info=devDependencies

[style]: https://img.shields.io/badge/code%20style-standard-yellow.svg
[style-url]: http://standardjs.com/

[travis]: http://img.shields.io/travis/posthtml/hapi-posthtml.svg
[travis-url]: https://travis-ci.org/posthtml/hapi-posthtml

[travis-rel]: http://img.shields.io/travis/posthtml/hapi-posthtml.svg?branch=release/1.0.0
[travis-rel-url]:https://travis-ci.org/posthtml/hapi-posthtml?branch=release/1.0.0

[travis-dev]: http://img.shields.io/travis/posthtml/hapi-posthtml.svg?branch=develop
[travis-dev-url]: https://travis-ci.org/posthtml/hapi-posthtml?branch=develop

[cover]: https://coveralls.io/repos/github/posthtml/hapi-posthtml/badge.svg?branch=master
[cover-url]: https://coveralls.io/github/posthtml/hapi-posthtml?branch=master

[cover-rel]: https://coveralls.io/repos/github/posthtml/hapi-posthtml/badge.svg?branch=release/1.0.0
[cover-rel-url]: https://coveralls.io/github/posthtml/hapi-posthtml?branch=release/1.0.0

[cover-dev]: https://coveralls.io/repos/github/posthtml/hapi-posthtml/badge.svg?branch=develop
[cover-dev-url]: https://coveralls.io/github/posthtml/hapi-posthtml?branch=develop

[license]: https://img.shields.io/github/license/posthtml/hapi-posthtml.svg
[license-url]: https://raw.githubusercontent.com/posthtml/hapi-posthtml/master/LICENSE
